==> ses-1.60.0-sources.jar: software/amazon/awscdk/services/ses/ReceiptRuleOptions.java <==
package software.amazon.awscdk.services.ses;

/**
 * Options to add a receipt rule to a receipt rule set.
 * <p>
 * EXPERIMENTAL
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.9.0 (build 5c646d5)", date = "2020-08-19T23:25:15.450Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.ses.$Module.class, fqn = "@aws-cdk/aws-ses.ReceiptRuleOptions")
@software.amazon.jsii.Jsii.Proxy(ReceiptRuleOptions.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
public interface ReceiptRuleOptions extends software.amazon.jsii.JsiiSerializable {

    /**
     * An ordered list of actions to perform on messages that match at least one of the recipient email addresses or domains specified in the receipt rule.
     * <p>
     * Default: - No actions.
     * <p>
     * EXPERIMENTAL
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    default @org.jetbrains.annotations.Nullable java.util.List<software.amazon.awscdk.services.ses.IReceiptRuleAction> getActions() {
        return null;
    }

    /**
     * An existing rule after which the new rule will be placed.
     * <p>
     * Default: - The new rule is inserted at the beginning of the rule list.
     * <p>
     * EXPERIMENTAL
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    default @org.jetbrains.annotations.Nullable software.amazon.awscdk.services.ses.IReceiptRule getAfter() {
        return null;
    }

    /**
     * Whether the rule is active.
     * <p>
     * Default: true
     * <p>
     * EXPERIMENTAL
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    default @org.jetbrains.annotations.Nullable java.lang.Boolean getEnabled() {
        return null;
    }

    /**
     * The name for the rule.
     * <p>
     * Default: - A CloudFormation generated name.
     * <p>
     * EXPERIMENTAL
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    default @org.jetbrains.annotations.Nullable java.lang.String getReceiptRuleName() {
        return null;
    }

    /**
     * The recipient domains and email addresses that the receipt rule applies to.
     * <p>
     * Default: - Match all recipients under all verified domains.
     * <p>
     * EXPERIMENTAL
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    default @org.jetbrains.annotations.Nullable java.util.List<java.lang.String> getRecipients() {
        return null;
    }

    /**
     * Whether to scan for spam and viruses.
     * <p>
     * Default: false
     * <p>
     * EXPERIMENTAL
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    default @org.jetbrains.annotations.Nullable java.lang.Boolean getScanEnabled() {
        return null;
    }

    /**
     * Whether Amazon SES should require that incoming email is delivered over a connection encrypted with Transport Layer Security (TLS).
     * <p>
     * Default: - Optional which will not check for TLS.
     * <p>
     * EXPERIMENTAL
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    default @org.jetbrains.annotations.Nullable software.amazon.awscdk.services.ses.TlsPolicy getTlsPolicy() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link ReceiptRuleOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link ReceiptRuleOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public static final class Builder implements software.amazon.jsii.Builder<ReceiptRuleOptions> {
        private java.util.List<software.amazon.awscdk.services.ses.IReceiptRuleAction> actions;
        private software.amazon.awscdk.services.ses.IReceiptRule after;
        private java.lang.Boolean enabled;
        private java.lang.String receiptRuleName;
        private java.util.List<java.lang.String> recipients;
        private java.lang.Boolean scanEnabled;
        private software.amazon.awscdk.services.ses.TlsPolicy tlsPolicy;

        /**
         * Sets the value of {@link ReceiptRuleOptions#getActions}
         * @param actions An ordered list of actions to perform on messages that match at least one of the recipient email addresses or domains specified in the receipt rule.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder actions(java.util.List<software.amazon.awscdk.services.ses.IReceiptRuleAction> actions) {
            this.actions = actions;
            return this;
        }

        /**
         * Sets the value of {@link ReceiptRuleOptions#getAfter}
         * @param after An existing rule after which the new rule will be placed.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder after(software.amazon.awscdk.services.ses.IReceiptRule after) {
            this.after = after;
            return this;
        }

        /**
         * Sets the value of {@link ReceiptRuleOptions#getEnabled}
         * @param enabled Whether the rule is active.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder enabled(java.lang.Boolean enabled) {
            this.enabled = enabled;
            return this;
        }

        /**
         * Sets the value of {@link ReceiptRuleOptions#getReceiptRuleName}
         * @param receiptRuleName The name for the rule.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder receiptRuleName(java.lang.String receiptRuleName) {
            this.receiptRuleName = receiptRuleName;
            return this;
        }

        /**
         * Sets the value of {@link ReceiptRuleOptions#getRecipients}
         * @param recipients The recipient domains and email addresses that the receipt rule applies to.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder recipients(java.util.List<java.lang.String> recipients) {
            this.recipients = recipients;
            return this;
        }

        /**
         * Sets the value of {@link ReceiptRuleOptions#getScanEnabled}
         * @param scanEnabled Whether to scan for spam and viruses.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder scanEnabled(java.lang.Boolean scanEnabled) {
            this.scanEnabled = scanEnabled;
            return this;
        }

        /**
         * Sets the value of {@link ReceiptRuleOptions#getTlsPolicy}
         * @param tlsPolicy Whether Amazon SES should require that incoming email is delivered over a connection encrypted with Transport Layer Security (TLS).
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder tlsPolicy(software.amazon.awscdk.services.ses.TlsPolicy tlsPolicy) {
            this.tlsPolicy = tlsPolicy;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link ReceiptRuleOptions}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        @Override
        public ReceiptRuleOptions build() {
            return new Jsii$Proxy(actions, after, enabled, receiptRuleName, recipients, scanEnabled, tlsPolicy);
        }
    }

    /**
     * An implementation for {@link ReceiptRuleOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements ReceiptRuleOptions {
        private final java.util.List<software.amazon.awscdk.services.ses.IReceiptRuleAction> actions;
        private final software.amazon.awscdk.services.ses.IReceiptRule after;
        private final java.lang.Boolean enabled;
        private final java.lang.String receiptRuleName;
        private final java.util.List<java.lang.String> recipients;
        private final java.lang.Boolean scanEnabled;
        private final software.amazon.awscdk.services.ses.TlsPolicy tlsPolicy;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.actions = this.jsiiGet("actions", software.amazon.jsii.NativeType.listOf(software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.ses.IReceiptRuleAction.class)));
            this.after = this.jsiiGet("after", software.amazon.awscdk.services.ses.IReceiptRule.class);
            this.enabled = this.jsiiGet("enabled", java.lang.Boolean.class);
            this.receiptRuleName = this.jsiiGet("receiptRuleName", java.lang.String.class);
            this.recipients = this.jsiiGet("recipients", software.amazon.jsii.NativeType.listOf(software.amazon.jsii.NativeType.forClass(java.lang.String.class)));
            this.scanEnabled = this.jsiiGet("scanEnabled", java.lang.Boolean.class);
            this.tlsPolicy = this.jsiiGet("tlsPolicy", software.amazon.awscdk.services.ses.TlsPolicy.class);
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        private Jsii$Proxy(final java.util.List<software.amazon.awscdk.services.ses.IReceiptRuleAction> actions, final software.amazon.awscdk.services.ses.IReceiptRule after, final java.lang.Boolean enabled, final java.lang.String receiptRuleName, final java.util.List<java.lang.String> recipients, final java.lang.Boolean scanEnabled, final software.amazon.awscdk.services.ses.TlsPolicy tlsPolicy) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.actions = actions;
            this.after = after;
            this.enabled = enabled;
            this.receiptRuleName = receiptRuleName;
            this.recipients = recipients;
            this.scanEnabled = scanEnabled;
            this.tlsPolicy = tlsPolicy;
        }

        @Override
        public java.util.List<software.amazon.awscdk.services.ses.IReceiptRuleAction> getActions() {
            return this.actions;
        }

        @Override
        public software.amazon.awscdk.services.ses.IReceiptRule getAfter() {
            return this.after;
        }

        @Override
        public java.lang.Boolean getEnabled() {
            return this.enabled;
        }

        @Override
        public java.lang.String getReceiptRuleName() {
            return this.receiptRuleName;
        }

        @Override
        public java.util.List<java.lang.String> getRecipients() {
            return this.recipients;
        }

        @Override
        public java.lang.Boolean getScanEnabled() {
            return this.scanEnabled;
        }

        @Override
        public software.amazon.awscdk.services.ses.TlsPolicy getTlsPolicy() {
            return this.tlsPolicy;
        }

        @Override
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            if (this.getActions() != null) {
                data.set("actions", om.valueToTree(this.getActions()));
            }
            if (this.getAfter() != null) {
                data.set("after", om.valueToTree(this.getAfter()));
            }
            if (this.getEnabled() != null) {
                data.set("enabled", om.valueToTree(this.getEnabled()));
            }
            if (this.getReceiptRuleName() != null) {
                data.set("receiptRuleName", om.valueToTree(this.getReceiptRuleName()));
            }
            if (this.getRecipients() != null) {
                data.set("recipients", om.valueToTree(this.getRecipients()));
            }
            if (this.getScanEnabled() != null) {
                data.set("scanEnabled", om.valueToTree(this.getScanEnabled()));
            }
            if (this.getTlsPolicy() != null) {
                data.set("tlsPolicy", om.valueToTree(this.getTlsPolicy()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@aws-cdk/aws-ses.ReceiptRuleOptions"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public boolean equals(Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            ReceiptRuleOptions.Jsii$Proxy that = (ReceiptRuleOptions.Jsii$Proxy) o;

            if (this.actions != null ? !this.actions.equals(that.actions) : that.actions != null) return false;
            if (this.after != null ? !this.after.equals(that.after) : that.after != null) return false;
            if (this.enabled != null ? !this.enabled.equals(that.enabled) : that.enabled != null) return false;
            if (this.receiptRuleName != null ? !this.receiptRuleName.equals(that.receiptRuleName) : that.receiptRuleName != null) return false;
            if (this.recipients != null ? !this.recipients.equals(that.recipients) : that.recipients != null) return false;
            if (this.scanEnabled != null ? !this.scanEnabled.equals(that.scanEnabled) : that.scanEnabled != null) return false;
            return this.tlsPolicy != null ? this.tlsPolicy.equals(that.tlsPolicy) : that.tlsPolicy == null;
        }

        @Override
        public int hashCode() {
            int result = this.actions != null ? this.actions.hashCode() : 0;
            result = 31 * result + (this.after != null ? this.after.hashCode() : 0);
            result = 31 * result + (this.enabled != null ? this.enabled.hashCode() : 0);
            result = 31 * result + (this.receiptRuleName != null ? this.receiptRuleName.hashCode() : 0);
            result = 31 * result + (this.recipients != null ? this.recipients.hashCode() : 0);
            result = 31 * result + (this.scanEnabled != null ? this.scanEnabled.hashCode() : 0);
            result = 31 * result + (this.tlsPolicy != null ? this.tlsPolicy.hashCode() : 0);
            return result;
        }
    }
}

==> ses-1.173.0-sources.jar: software/amazon/awscdk/services/ses/ReceiptRuleOptions.java <==
package software.amazon.awscdk.services.ses;

/**
 * Options to add a receipt rule to a receipt rule set.
 * <p>
 * Example:
 * <p>
 * <blockquote><pre>
 * ReceiptRuleSet ruleSet = new ReceiptRuleSet(this, "RuleSet");
 * ReceiptRule awsRule = ruleSet.addRule("Aws", ReceiptRuleOptions.builder()
 *         .recipients(List.of("aws.com"))
 *         .build());
 * </pre></blockquote>
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.67.0 (build 2c027f5)", date = "2022-09-16T18:50:30.644Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.ses.$Module.class, fqn = "@aws-cdk/aws-ses.ReceiptRuleOptions")
@software.amazon.jsii.Jsii.Proxy(ReceiptRuleOptions.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface ReceiptRuleOptions extends software.amazon.jsii.JsiiSerializable {

    /**
     * An ordered list of actions to perform on messages that match at least one of the recipient email addresses or domains specified in the receipt rule.
     * <p>
     * Default: - No actions.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.util.List<software.amazon.awscdk.services.ses.IReceiptRuleAction> getActions() {
        return null;
    }

    /**
     * An existing rule after which the new rule will be placed.
     * <p>
     * Default: - The new rule is inserted at the beginning of the rule list.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable software.amazon.awscdk.services.ses.IReceiptRule getAfter() {
        return null;
    }

    /**
     * Whether the rule is active.
     * <p>
     * Default: true
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.Boolean getEnabled() {
        return null;
    }

    /**
     * The name for the rule.
     * <p>
     * Default: - A CloudFormation generated name.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.String getReceiptRuleName() {
        return null;
    }

    /**
     * The recipient domains and email addresses that the receipt rule applies to.
     * <p>
     * Default: - Match all recipients under all verified domains.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.util.List<java.lang.String> getRecipients() {
        return null;
    }

    /**
     * Whether to scan for spam and viruses.
     * <p>
     * Default: false
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.Boolean getScanEnabled() {
        return null;
    }

    /**
     * Whether Amazon SES should require that incoming email is delivered over a connection encrypted with Transport Layer Security (TLS).
     * <p>
     * Default: - Optional which will not check for TLS.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable software.amazon.awscdk.services.ses.TlsPolicy getTlsPolicy() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link ReceiptRuleOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link ReceiptRuleOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<ReceiptRuleOptions> {
        java.util.List<software.amazon.awscdk.services.ses.IReceiptRuleAction> actions;
        software.amazon.awscdk.services.ses.IReceiptRule after;
        java.lang.Boolean enabled;
        java.lang.String receiptRuleName;
        java.util.List<java.lang.String> recipients;
        java.lang.Boolean scanEnabled;
        software.amazon.awscdk.services.ses.TlsPolicy tlsPolicy;

        /**
         * Sets the value of {@link ReceiptRuleOptions#getActions}
         * @param actions An ordered list of actions to perform on messages that match at least one of the recipient email addresses or domains specified in the receipt rule.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @SuppressWarnings("unchecked")
        public Builder actions(java.util.List<? extends software.amazon.awscdk.services.ses.IReceiptRuleAction> actions) {
            this.actions = (java.util.List<software.amazon.awscdk.services.ses.IReceiptRuleAction>)actions;
            return this;
        }

        /**
         * Sets the value of {@link ReceiptRuleOptions#getAfter}
         * @param after An existing rule after which the new rule will be placed.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder after(software.amazon.awscdk.services.ses.IReceiptRule after) {
            this.after = after;
            return this;
        }

        /**
         * Sets the value of {@link ReceiptRuleOptions#getEnabled}
         * @param enabled Whether the rule is active.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder enabled(java.lang.Boolean enabled) {
            this.enabled = enabled;
            return this;
        }

        /**
         * Sets the value of {@link ReceiptRuleOptions#getReceiptRuleName}
         * @param receiptRuleName The name for the rule.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder receiptRuleName(java.lang.String receiptRuleName) {
            this.receiptRuleName = receiptRuleName;
            return this;
        }

        /**
         * Sets the value of {@link ReceiptRuleOptions#getRecipients}
         * @param recipients The recipient domains and email addresses that the receipt rule applies to.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder recipients(java.util.List<java.lang.String> recipients) {
            this.recipients = recipients;
            return this;
        }

        /**
         * Sets the value of {@link ReceiptRuleOptions#getScanEnabled}
         * @param scanEnabled Whether to scan for spam and viruses.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder scanEnabled(java.lang.Boolean scanEnabled) {
            this.scanEnabled = scanEnabled;
            return this;
        }

        /**
         * Sets the value of {@link ReceiptRuleOptions#getTlsPolicy}
         * @param tlsPolicy Whether Amazon SES should require that incoming email is delivered over a connection encrypted with Transport Layer Security (TLS).
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder tlsPolicy(software.amazon.awscdk.services.ses.TlsPolicy tlsPolicy) {
            this.tlsPolicy = tlsPolicy;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link ReceiptRuleOptions}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public ReceiptRuleOptions build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link ReceiptRuleOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements ReceiptRuleOptions {
        private final java.util.List<software.amazon.awscdk.services.ses.IReceiptRuleAction> actions;
        private final software.amazon.awscdk.services.ses.IReceiptRule after;
        private final java.lang.Boolean enabled;
        private final java.lang.String receiptRuleName;
        private final java.util.List<java.lang.String> recipients;
        private final java.lang.Boolean scanEnabled;
        private final software.amazon.awscdk.services.ses.TlsPolicy tlsPolicy;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.actions = software.amazon.jsii.Kernel.get(this, "actions", software.amazon.jsii.NativeType.listOf(software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.ses.IReceiptRuleAction.class)));
            this.after = software.amazon.jsii.Kernel.get(this, "after", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.ses.IReceiptRule.class));
            this.enabled = software.amazon.jsii.Kernel.get(this, "enabled", software.amazon.jsii.NativeType.forClass(java.lang.Boolean.class));
            this.receiptRuleName = software.amazon.jsii.Kernel.get(this, "receiptRuleName", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.recipients = software.amazon.jsii.Kernel.get(this, "recipients", software.amazon.jsii.NativeType.listOf(software.amazon.jsii.NativeType.forClass(java.lang.String.class)));
            this.scanEnabled = software.amazon.jsii.Kernel.get(this, "scanEnabled", software.amazon.jsii.NativeType.forClass(java.lang.Boolean.class));
            this.tlsPolicy = software.amazon.jsii.Kernel.get(this, "tlsPolicy", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.ses.TlsPolicy.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        @SuppressWarnings("unchecked")
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.actions = (java.util.List<software.amazon.awscdk.services.ses.IReceiptRuleAction>)builder.actions;
            this.after = builder.after;
            this.enabled = builder.enabled;
            this.receiptRuleName = builder.receiptRuleName;
            this.recipients = builder.recipients;
            this.scanEnabled = builder.scanEnabled;
            this.tlsPolicy = builder.tlsPolicy;
        }

        @Override
        public final java.util.List<software.amazon.awscdk.services.ses.IReceiptRuleAction> getActions() {
            return this.actions;
        }

        @Override
        public final software.amazon.awscdk.services.ses.IReceiptRule getAfter() {
            return this.after;
        }

        @Override
        public final java.lang.Boolean getEnabled() {
            return this.enabled;
        }

        @Override
        public final java.lang.String getReceiptRuleName() {
            return this.receiptRuleName;
        }

        @Override
        public final java.util.List<java.lang.String> getRecipients() {
            return this.recipients;
        }

        @Override
        public final java.lang.Boolean getScanEnabled() {
            return this.scanEnabled;
        }

        @Override
        public final software.amazon.awscdk.services.ses.TlsPolicy getTlsPolicy() {
            return this.tlsPolicy;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            if (this.getActions() != null) {
                data.set("actions", om.valueToTree(this.getActions()));
            }
            if (this.getAfter() != null) {
                data.set("after", om.valueToTree(this.getAfter()));
            }
            if (this.getEnabled() != null) {
                data.set("enabled", om.valueToTree(this.getEnabled()));
            }
            if (this.getReceiptRuleName() != null) {
                data.set("receiptRuleName", om.valueToTree(this.getReceiptRuleName()));
            }
            if (this.getRecipients() != null) {
                data.set("recipients", om.valueToTree(this.getRecipients()));
            }
            if (this.getScanEnabled() != null) {
                data.set("scanEnabled", om.valueToTree(this.getScanEnabled()));
            }
            if (this.getTlsPolicy() != null) {
                data.set("tlsPolicy", om.valueToTree(this.getTlsPolicy()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@aws-cdk/aws-ses.ReceiptRuleOptions"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            ReceiptRuleOptions.Jsii$Proxy that = (ReceiptRuleOptions.Jsii$Proxy) o;

            if (this.actions != null ? !this.actions.equals(that.actions) : that.actions != null) return false;
            if (this.after != null ? !this.after.equals(that.after) : that.after != null) return false;
            if (this.enabled != null ? !this.enabled.equals(that.enabled) : that.enabled != null) return false;
            if (this.receiptRuleName != null ? !this.receiptRuleName.equals(that.receiptRuleName) : that.receiptRuleName != null) return false;
            if (this.recipients != null ? !this.recipients.equals(that.recipients) : that.recipients != null) return false;
            if (this.scanEnabled != null ? !this.scanEnabled.equals(that.scanEnabled) : that.scanEnabled != null) return false;
            return this.tlsPolicy != null ? this.tlsPolicy.equals(that.tlsPolicy) : that.tlsPolicy == null;
        }

        @Override
        public final int hashCode() {
            int result = this.actions != null ? this.actions.hashCode() : 0;
            result = 31 * result + (this.after != null ? this.after.hashCode() : 0);
            result = 31 * result + (this.enabled != null ? this.enabled.hashCode() : 0);
            result = 31 * result + (this.receiptRuleName != null ? this.receiptRuleName.hashCode() : 0);
            result = 31 * result + (this.recipients != null ? this.recipients.hashCode() : 0);
            result = 31 * result + (this.scanEnabled != null ? this.scanEnabled.hashCode() : 0);
            result = 31 * result + (this.tlsPolicy != null ? this.tlsPolicy.hashCode() : 0);
            return result;
        }
    }
}
